setDuration static method
From the date and time this method is called, the notification for the target ID will not be displayed for the Duration passed as an argument.
Implementation
static Future<LongTimeNoNotification> setDuration({required String id, required Duration duration}) {
return LongTimeNoNotificationDelegate.set(
id: id,
currentDateTime: DateTime.now(),
duration: duration,
repository: _repository,
);
}